volume: US Customary: [ fluid ounces ]: https://en.wikipedia.org/wiki/Fluid_ounce 1 US Customary fluid ounce = 29.5735 millilitres System Internation: [ litres, liters ] Priorities: [ ] language translations: [ ] unicode + direction: https://en.wikipedia.org/wiki/Unicode [ ] English: [ ] Mandarin: [ ] Russia: [ ] Hindi: https://en.wikipedia.org/wiki/List_of_languages_by_number_of_native_speakers_in_India